<?xml version="1.0" ?><!DOCTYPE TS><TS language="am_ET" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="86"/>
        <location filename="../main.cpp" line="118"/>
        <source>Deepin Movie</source>
        <translation>ሙቪ</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
        <translation>ዲፕኢን ሙቪ በ ጥሩ-የ ተዘጋጀ እና የ ሙሉ-ገጽታ ቪዲዮ ማጫወቻ ነው: ድንበሮቹ በ ቀላሉ የ ተዘጋጁ ናቸው: የ አካባቢ እና በርካታ የ ቪዲዮ አቀራረቦችን ይደግፋል</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="116"/>
        <source>Invalid folder</source>
        <translation>ዋጋ የሌለው ፎልደር</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="130"/>
        <source>Open Folder</source>
        <translation>ፎልደር መክፋቻ</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="121"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>እርስዎ ይህን ፎልደር ለ መጠቀም በቂ ፍቃድ የለዎትም </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="5"/>
        <source>Auto add similar files to play</source>
        <translation>በራሱ ተመሳሳይ ፋይሎች ለ ማጫወቻ መጨመሪያ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="6"/>
        <source>Clear playlist when exit</source>
        <translation>በምወጣ ጊዜ የ ማጫወቻውን ዝርዝር ማጽጃ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="7"/>
        <source>Show video preview on mouseover</source>
        <translation>አይጥ በላዩ ላይ ሲንሳፈፍ የ ቪዲዮ ቅድመ እይታ ማሳያ </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="8"/>
        <source>Open a new player for each file played</source>
        <translation>ለሚጫወተው እያንዳንዱ ፋይል አዲስ ማጫወቻ መክፈቻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="9"/>
        <source>Pause when minimized</source>
        <translation>በሚያንስ ጊዜ ማስቆሚያ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="10"/>
        <source>Remember playback position</source>
        <translation>የ መልሶ ማጫወቻ ቦታ አስታውስ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="11"/>
        <source>Path</source>
        <translation>መንገድ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="12"/>
        <source>Basic</source>
        <translation>መሰረታዊ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="13"/>
        <source>Play</source>
        <translation>ማጫወቻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="14"/>
        <location filename="../common/settings_translation.cpp" line="19"/>
        <source>Screenshot</source>
        <translation>መመልከቻውን ፎቶ ማንሻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="15"/>
        <source>Shortcuts</source>
        <translation>አቋራጭ </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="16"/>
        <source>File</source>
        <translation>ፋይል</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="17"/>
        <source>Frame/Sound</source>
        <translation>ክፈፍ/ዽምፅ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="18"/>
        <source>Playback</source>
        <translation>በድጋሚ ማጫወቻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="20"/>
        <location filename="../common/settings_translation.cpp" line="21"/>
        <source>Subtitle</source>
        <translation>ንዑስ አርእስት</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="22"/>
        <source>Font Style</source>
        <translation>የ ፊደል ዘዴ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="23"/>
        <source>Restore Defaults</source>
        <translation>ነባር እንደ ነበር መመለሻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="24"/>
        <source>Open file</source>
        <translation>ፋይል መክፈቻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="25"/>
        <source>Open next</source>
        <translation>የሚቀጥለውን መክፈቻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="26"/>
        <source>Open previous</source>
        <translation>ቀደም ያለውን መክፈቻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="27"/>
        <source>Mini mode</source>
        <translation>በትንሽ ዘዴ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="28"/>
        <source>Mute</source>
        <translation>መቀነሻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="29"/>
        <source>volume down</source>
        <translation>መጠን መቀነሻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="30"/>
        <source>Volume up</source>
        <translation>መጠን መጨመሪያ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="31"/>
        <source>Speed up</source>
        <translation>ፍጥነት መጨመሪያ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="32"/>
        <source>Speed down</source>
        <translation>ፍጥነት መቀነሻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="33"/>
        <source>Fullscreen</source>
        <translation>በሙሉ መመልከቻ ዘዴ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="34"/>
        <source>Pause/Play</source>
        <translation>ማጫወቻ/ማስቆሚያ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="35"/>
        <source>Playlist</source>
        <translation>የማጫወቻ ዝርዝር</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="36"/>
        <source>Reset speed</source>
        <translation>ፍጥነት እንደ ነበር መመለሻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="37"/>
        <source>Rewind</source>
        <translation>ወደ ኋላ ማጠንጠኛ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="38"/>
        <source>Forward</source>
        <translation>ወደ ፊት</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="39"/>
        <source>Burst screenshot</source>
        <translation>ፍንዳታ የ መመልከቻ ፎቶ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="40"/>
        <source>Film screenshot</source>
        <translation>የ ፊልም መመልከቻ ፎቶ ማንሻ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="41"/>
        <source>0.5s backward</source>
        <translation>0.5s ወደ ኋላ </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="42"/>
        <source>0.5s forward</source>
        <translation>0.5s ወደ ፊት</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="43"/>
        <source>Font</source>
        <translation>ፊደል</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="44"/>
        <source>Font Size</source>
        <translation>የ ፊደል መጠን:</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>መሰረዣ</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="42"/>
        <source>Confirm</source>
        <translation>ማረጋገጫ</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="46"/>
        <source>Please enter the URL:</source>
        <translation>እባክዎን ያስገቡ URL:</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../common/actions.cpp" line="82"/>
        <location filename="../common/actions.cpp" line="102"/>
        <source>Open File</source>
        <translation>ፋይል መክፈቻ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="84"/>
        <location filename="../common/actions.cpp" line="265"/>
        <source>Settings</source>
        <translation>ማሰናጃዎች</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="85"/>
        <source>Light Theme</source>
        <translation>የ ብርሃን ገጽታ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="108"/>
        <source>Fullscreen</source>
        <translation>በሙሉ መመልከቻ ዘዴ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="110"/>
        <source>Always on Top</source>
        <translation>ሁል ጊዜ ከ ላይ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="280"/>
        <source>Film info</source>
        <translation>የ ፊልም መረጃ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="83"/>
        <location filename="../common/actions.cpp" line="103"/>
        <source>Open Folder</source>
        <translation>ፎልደር መክፋቻ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="104"/>
        <source>Open URL</source>
        <translation>URL መክፈቻ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="105"/>
        <source>Open CD/DVD</source>
        <translation>ሲዲ/ዲቪዲ መክፈቻ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="109"/>
        <source>Mini Mode</source>
        <translation>በ ትንሽ ዘዴ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="115"/>
        <source>Play Mode</source>
        <translation>ማጫወቻ ዘዴ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="118"/>
        <source>Order Play</source>
        <translation>በ ተራ ማጫወቻ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="119"/>
        <source>Shuffle Play</source>
        <translation>መበወዣ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="120"/>
        <source>Single Play</source>
        <translation>ነጠላ ማጫወቻ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="121"/>
        <source>Single Loop</source>
        <translation>ነጠላ ዙር</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="122"/>
        <source>List Loop</source>
        <translation>ዝርዝር ዙር</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="129"/>
        <source>Frame</source>
        <translation>ክፈፍ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="132"/>
        <source>Default</source>
        <translation>ነባር</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="140"/>
        <source>Clockwise</source>
        <translation>ከ ግራ ወደ ቀኝ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="141"/>
        <source>Counterclockwise</source>
        <translation>ከ ቀኝ ወደ ግራ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="148"/>
        <source>Sound</source>
        <translation>ድምፅ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="151"/>
        <source>Channel</source>
        <translation>ጣቢያ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="154"/>
        <source>Stereo</source>
        <translation>ስቴሪዮ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="155"/>
        <source>Left channel</source>
        <translation>የ ግራ ጣቢያ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="156"/>
        <source>Right channel</source>
        <translation>የ ቀኝ ጣቢያ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="162"/>
        <source>Track</source>
        <translation>ተረኛ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="172"/>
        <source>Subtitle</source>
        <translation>ንዑስ አርእስት</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="173"/>
        <source>Load</source>
        <translation>መጫኛ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="174"/>
        <source>Online Search</source>
        <translation>በ መስመር ላይ መፈለጊያ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="178"/>
        <source>Select</source>
        <translation>ይምረጡ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="182"/>
        <source>Hide</source>
        <translation>መደበቂያ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="186"/>
        <source>Encodings</source>
        <translation>መቀየሪያ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="254"/>
        <source>Screenshot</source>
        <translation>መመልከቻውን ፎቶ ማንሻ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="255"/>
        <source>Film Screenshot</source>
        <translation>የ ፊልም መመልከቻ ፎቶ ማንሻ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="256"/>
        <source>Burst Shooting</source>
        <translation>ፍንዳታ ፎቶ ማንሻ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="263"/>
        <source>Playlist</source>
        <translation>የማጫወቻ ዝርዝር</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="264"/>
        <source>Film Info</source>
        <translation>የ ፊልም መረጃ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="278"/>
        <source>Clear playlist</source>
        <translation>ዝርዝር ማጫወቻ ማጽጃ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="279"/>
        <source>Display in file manager</source>
        <translation>በ ፋይል አስተዳዳሪ እስጥ ማሳያ</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
        <source>duration: %1</source>
        <translation>የሚፈጀው ጊዜ %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
        <source>resolution: %1</source>
        <translation>ሪዞሊሽን: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
        <source>size: %1</source>
        <translation>መጠን: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
        <source>save</source>
        <translation>ማስቀመጫ</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../common/mainwindow.cpp" line="785"/>
        <location filename="../common/mainwindow.cpp" line="2279"/>
        <location filename="../common/mainwindow.cpp" line="2374"/>
        <source>Deepin Movie</source>
        <translation>ሙቪ</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="698"/>
        <location filename="../common/mainwindow.cpp" line="1796"/>
        <source>Load successfully</source>
        <translation>ተሳክቶ ተጭኗል </translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="698"/>
        <location filename="../common/mainwindow.cpp" line="1796"/>
        <source>Load failed</source>
        <translation>መጫን አልተቻለም</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1402"/>
        <source>No device found</source>
        <translation>ምንም አካል አልተገኘም</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1420"/>
        <source>Parse Failed</source>
        <translation>መተንተን አልተቻለም</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1427"/>
        <source>Open Folder</source>
        <translation>ፎልደር መክፋቻ</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1442"/>
        <location filename="../common/mainwindow.cpp" line="1459"/>
        <location filename="../common/mainwindow.cpp" line="1791"/>
        <source>Open File</source>
        <translation>ፋይል መክፈቻ</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1444"/>
        <location filename="../common/mainwindow.cpp" line="1461"/>
        <source>All videos (%1)</source>
        <translation>ሁሉንም ቪዲዮዎች (*)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1659"/>
        <source>Muted</source>
        <translation>መቀነሻ</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1662"/>
        <location filename="../common/mainwindow.cpp" line="1674"/>
        <location filename="../common/mainwindow.cpp" line="1684"/>
        <location filename="../common/mainwindow.cpp" line="1691"/>
        <source>Volume: %1%</source>
        <translation>መጠን: %1</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1756"/>
        <location filename="../common/mainwindow.cpp" line="1764"/>
        <source>Subtitle %1: %2s</source>
        <translation>ንዑስ አርእስት %1: %2s</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1757"/>
        <location filename="../common/mainwindow.cpp" line="1765"/>
        <source>delayed</source>
        <translation>ዘግይቷል</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1757"/>
        <location filename="../common/mainwindow.cpp" line="1765"/>
        <source>advanced</source>
        <translation>የረቀቀ</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1772"/>
        <location filename="../common/mainwindow.cpp" line="1779"/>
        <location filename="../common/mainwindow.cpp" line="1786"/>
        <source>Speed: %1x</source>
        <translation>ፍጥነት: %1x</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1793"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</source>
        <translation>ንዑስ አርእስት (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1855"/>
        <source>View</source>
        <translation>መመልከቻ</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1866"/>
        <source>Movie Screenshot</source>
        <translation>የ ሙቪ መመልከቻ ፎቶ ማንሻ</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1867"/>
        <source>Saved to</source>
        <translation>ተቀምጧል ወደ</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1881"/>
        <location filename="../common/mainwindow.cpp" line="1952"/>
        <source>The screenshot is saved</source>
        <translation>የ መመልከቻው ፎቶ ተቀምጧል </translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1881"/>
        <source>The screenshot is failed to save</source>
        <translation>የ መመልከቻው ፎቶ ማስቀመጥ አክተቻለም </translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="2039"/>
        <location filename="../common/mainwindow.cpp" line="2728"/>
        <source>Invalid file: %1</source>
        <translation>ዋጋ የሌለው ፋይል: %1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
        <source>File Type:</source>
        <translation>የፋይል አይነት:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
        <source>Resolution:</source>
        <translation>ሪዞሊሽን:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
        <source>File Size:</source>
        <translation>የ ፊደል መጠን:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
        <source>Duration:</source>
        <translation>የሚፈጀው ጊዜ</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
        <source>File Path:</source>
        <translation>የ ፋይል መንገድ</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1017"/>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1035"/>
        <source>[internal]</source>
        <translation>[የ ውስጥ]</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../widgets/playlist_widget.cpp" line="192"/>
        <location filename="../widgets/playlist_widget.cpp" line="227"/>
        <location filename="../widgets/playlist_widget.cpp" line="402"/>
        <source>File does not exist</source>
        <translation>ፋይሉ ቀደም ብሎ አልነበረም</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../common/dmr_settings.cpp" line="155"/>
        <source>%1/DMovie%2.jpg</source>
        <translation>%1/DMovie%2.jpg</translation>
    </message>
    <message>
        <location filename="../common/dmr_settings.cpp" line="161"/>
        <source>%1/DMovie%2(%3).jpg</source>
        <translation>%1/DMovie%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="889"/>
        <source>Play</source>
        <translation>ማጫወቻ</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="685"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Previous</source>
        <translation>ቀደም ያለው</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="686"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Next</source>
        <translation>ይቀጥሉ</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="687"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Subtitles</source>
        <translation>ንዑስ አርእስቶች</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="688"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Playlist</source>
        <translation>የማጫወቻ ዝርዝር</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="689"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="876"/>
        <source>Fullscreen</source>
        <translation>በሙሉ መመልከቻ ዘዴ</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="683"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Play/Pause</source>
        <translation>ማጫወቻ/ማስቆሚያ</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="873"/>
        <source>Exit fullscreen</source>
        <translation>ከ ሙሉ መመልከቻው ዘዴ መውጫ</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="886"/>
        <source>Pause</source>
        <translation>ማስቆሚያ</translation>
    </message>
</context>
</TS>